@@ -50,8 +50,8 @@ downloads, installation and source code.
 
 __Conventions__  = 'CF-1.5'
 __author__       = 'David Hassell'
-__date__         = '09 December 2015'
-__version__      = '1.1.3'
+__date__         = '09 February 2016'
+__version__      = '1.1.4'
 
 from distutils.version import StrictVersion
 import imp
