@@ -26,10 +26,8 @@ from ..                 import __Conventions__
 from ..cfdatetime       import dt2rt
 from ..coordinate       import Coordinate
 from ..coordinatebounds import CoordinateBounds
-from ..field            import Field
-from ..fieldlist        import FieldList
+from ..field            import Field, FieldList
 from ..functions        import equals, flat, relpath, abspath
-from ..variable         import Variable
 
 from ..data.data        import Data
 
@@ -400,7 +398,7 @@ def _write_attributes(netcdf_var, netcdf_attrs):
 
 
 '''
-    if not hasattr(netcdf_var, 'setncatts'):
+    if hasattr(netcdf_var, 'setncatts'):
         # Use the faster setncatts
         netcdf_var.setncatts(netcdf_attrs)
     else:
@@ -1519,11 +1517,11 @@ def _create_netcdf_variable(ncvar, dimensions, cfvar, omit=(), extra={},
                             g=None):
     '''
 
-Create a netCDF variable fron 'cfvar' with name 'ncvar' and dimensions
-'ncdimensions'. The netCDF variable's properties are given by
-cfvar.properties(), less any given by the 'omit' argument. If a new
+Create a netCDF variable from *cfvar* with name *ncvar* and dimensions
+*ncdimensions*. The new netCDF variable's properties are given by
+cfvar.properties(), less any given by the *omit* argument. If a new
 string-length netCDF dimension is required then it will also be
-created. The 'seen' dictionary is updated for 'cfvar'.
+created. The ``seen`` dictionary is updated for *cfvar*.
 
 .. note:: This function updates ``g['strlenN']``,
           ``g['ncdim_to_size']``, ``g['netcdf']``, ``g['nc']``,
@@ -1671,6 +1669,7 @@ created. The 'seen' dictionary is updated for 'cfvar'.
         # -------------------------------------------------------------
         if data is not None:  
 
+            # Find the missing data values, if any.
             if not fill_value:
                 missing_data = None
             else:
@@ -1693,13 +1692,13 @@ created. The 'seen' dictionary is updated for 'cfvar'.
             for partition in data.partitions.flat:
                 array = partition.dataarray(**pda_args)   
 
+                # Convert booleans to integers
                 if array.dtype is numpy_dtype(bool):
                     array = array.astype('int32')                    
 
+                # Check that the array doesn't contain any elements
+                # which are equal to any of the missing data values
                 if missing_data:
-                    # Check that the array doesn't contain any
-                    # elements which are equal to any of the missing
-                    # data values
                     if partition.masked:
                         temp_array = array.compressed()
                     else:
@@ -1711,6 +1710,7 @@ created. The 'seen' dictionary is updated for 'cfvar'.
 cfvar)
                 #--- End: if
 
+                # Copy the array into the netCDF variable
                 g['nc'][ncvar][partition.indices] = array        
 
                 partition.close()
@@ -1767,8 +1767,6 @@ def _write_a_field(f, add_to_seen=False, allow_data_expand_dims=True,
     domain     = f.domain
     dimensions = domain._axes
 
-#    g['axis_to_ncdim'] = {}
-
     # Mapping of field axis identifiers to netCDF dimension names
     axis_to_ncdim = {}
 
@@ -1811,7 +1809,7 @@ def _write_a_field(f, add_to_seen=False, allow_data_expand_dims=True,
 
                     # Expand the field's data array to include this
                     # axis
-                    f.expand_dims(0, axis=axis, i=True) 
+                    f.expand_dims(0, axes=axis, i=True) 
                 else:
                     # There are NO auxiliary coordinates/cell measures
                     # which span this axis, so write the dimension
@@ -1831,7 +1829,7 @@ def _write_a_field(f, add_to_seen=False, allow_data_expand_dims=True,
                 # The data array doesn't span the axis but an
                 # auxiliary coordinate or cell measure does, so expand
                 # the data array to include it.
-                f.expand_dims(0, axis=axis, i=True)
+                f.expand_dims(0, axes=axis, i=True)
                 data_axes.append(axis)
             #--- End: if
 
