@@ -137,9 +137,15 @@ grid may have an associated mask.
         #--- End: if
         
         # Get the bounds, creating them if they do not exist
-        x_bounds = lon.get_bounds(create=True).array
+        x_bounds = lon.get_bounds(create=True)
         y_bounds = lat.get_bounds(create=True).clip(-90, 90, 'degrees').array
         
+        # If not set as cyclic already, check for cyclicity
+        if not cyclic:
+            cyclic = abs(x_bounds.datum(-1) - x_bounds.datum(0)) != Data(360,
+                     'degrees')
+        x_bounds = x_bounds.array
+        
         # Create empty grid
         max_index = numpy_array([lon.size, lat.size], dtype='int32')
         staggerLocs = [ESMF.StaggerLoc.CORNER, ESMF.StaggerLoc.CENTER]
