@@ -2225,12 +2225,12 @@ handles units of months and years.
         if units in ('month', 'months'):
             # Convert months to days
             unit_string = unit_string.replace(units, 'days', 1)
-            time_value = time_value*365.242198781/12
+            time_value = numpy_array(time_value)*365.242198781/12
 
         elif units in ('year', 'years', 'yr'):
             # Convert years to days
             unit_string = unit_string.replace(units, 'days', 1)
-            time_value = time_value*365.242198781
+            time_value = numpy_array(time_value)*365.242198781
 
         u = _netCDF4_netcdftime_utime(unit_string, self.calendar)        
         return u.num2date(time_value)
