@@ -41,6 +41,7 @@ class DataTest(unittest.TestCase):
 #    test_only = ('test_dumpd_loadd',)
 #    test_only = ('test_Data_year_month_day_hour_minute_second',)
 #    test_only =  ('test_Data_BINARY_AND_UNARY_OPERATORS',)
+#    test_only =  ('test_Data_clip',)
 
     # Variables for _collapse
     a = numpy.arange(-100, 200., dtype=float).reshape(3, 4, 5, 5) 
@@ -207,6 +208,30 @@ class DataTest(unittest.TestCase):
         cf.CHUNKSIZE(self.original_chunksize)
     #--- End: def
 
+    def test_Data_clip(self):
+        if self.test_only and inspect.stack()[0][3] not in self.test_only:
+            return
+
+        c0 = -53.234
+        c1 = 34.345456567
+
+        a = self.a + 0.34567
+        ac = numpy.clip(a, c0, c1)
+
+        for chunksize in self.chunk_sizes: 
+            cf.CHUNKSIZE(chunksize)          
+            d = cf.Data(a, 'km')
+            e = d.clip(c0, c1)
+            self.assertTrue((e.array == ac).all())
+            e = d.clip(c0*1000, c1*1000, units='m')
+            self.assertTrue((e.array == ac).all())
+            d.clip(c0*100, c1*100, units='10m', i=True)
+            self.assertTrue(d.allclose(ac, rtol=1e-05, atol=1e-08))
+        #--- End: for
+
+        cf.CHUNKSIZE(self.original_chunksize)
+    #--- End: def
+
     def test_Data_dtarray(self):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
@@ -337,6 +362,24 @@ class DataTest(unittest.TestCase):
         cf.CHUNKSIZE(self.original_chunksize)
     #--- End: def      
 
+    def test_Data_round(self):
+        if self.test_only and inspect.stack()[0][3] not in self.test_only:
+            return
+
+        for decimals in range(-8, 8):
+            a = self.a + 0.34567
+            c = numpy.round(a, decimals=decimals)
+                
+            for chunksize in self.chunk_sizes:   
+                cf.CHUNKSIZE(chunksize)          
+                d = cf.Data(a)
+                d.round(decimals=decimals, i=True)
+                self.assertTrue(d.shape == c.shape)
+                self.assertTrue((d.array == c).all())
+        #--- End: for
+        cf.CHUNKSIZE(self.original_chunksize)
+    #--- End: def      
+
     def test_Data_datum(self):
         if self.test_only and inspect.stack()[0][3] not in self.test_only:
             return
