@@ -343,7 +343,29 @@ class FieldTest(unittest.TestCase):
                 #--- End: for
                 a = a.min(axis=0)
                 self.assertTrue(numpy.allclose(a, g.array[m % 12]))
-            #--- End: for
+            #--- End: for  
+
+            g = f.collapse('T: mean', group=360)
+
+            for group in (cf.M(12), 
+                          cf.M(12, month=12),
+                          cf.M(12, day=16),
+                          cf.M(12, year=1999, month=11, day=27)):
+                g = f.collapse('T: mean', group=group)
+                bound = g.coord('T').bounds.dtarray[0, 1]
+                self.assertTrue(bound.month == group.month, "group=%s" % group)
+                self.assertTrue(bound.day   == group.day  , "group=%s" % group)
+            #--- End: for  
+
+            for group in (cf.D(30), 
+                          cf.D(30, month=12),
+                          cf.D(30, day=16),
+                          cf.D(30, year=1999, month=11, day=27)):
+                g = f.collapse('T: mean', group=group)
+                bound = g.coord('T').bounds.dtarray[0, 1]
+                self.assertTrue(bound.day == group.day, "group=%s" % group)
+            #--- End: for  
+
         #--- End: for    
 
         cf.CHUNKSIZE(self.original_chunksize)
